/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_H3sn8CpB);
  numBytes += sPhasor_k_init(&sPhasor_HIREvdEG, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_59wtxHrn);
  numBytes += sRPole_init(&sRPole_yG3CRDc5);
  numBytes += sRPole_init(&sRPole_TwIVSpr7);
  numBytes += sTabhead_init(&sTabhead_ZjUpAEcM, &hTable_shzvadb8);
  numBytes += sTabread_init(&sTabread_QI7DM5Lu, &hTable_shzvadb8, false);
  numBytes += sTabread_init(&sTabread_6wJfvaXg, &hTable_shzvadb8, false);
  numBytes += sLine_init(&sLine_kyvd6G8O);
  numBytes += sTabhead_init(&sTabhead_6rce78HJ, &hTable_JE6ljEEX);
  numBytes += sTabread_init(&sTabread_aiXOyJv2, &hTable_JE6ljEEX, false);
  numBytes += sTabread_init(&sTabread_g5ocwg1P, &hTable_JE6ljEEX, false);
  numBytes += sLine_init(&sLine_0rE0H9rZ);
  numBytes += sTabwrite_init(&sTabwrite_ZKEHILGr, &hTable_JE6ljEEX);
  numBytes += sTabwrite_init(&sTabwrite_CIzgmCer, &hTable_shzvadb8);
  numBytes += cVar_init_f(&cVar_5CTQWfVC, 0.0f);
  numBytes += cVar_init_f(&cVar_jiG3qgQB, 0.0f);
  numBytes += cVar_init_f(&cVar_LLEf967r, 0.0f);
  numBytes += cVar_init_f(&cVar_l0hf1UN2, 0.0f);
  numBytes += cVar_init_s(&cVar_UXeJIbHS, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_yVaiaPsc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cO1tYZqI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8QGK8ZVM, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_1UUKUzd6, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_XdazxHx0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3RK3o5MP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rBlwhZ90, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_S3kUwRir, 0.0f);
  numBytes += cDelay_init(this, &cDelay_DQeMmyz9, 0.0f);
  numBytes += hTable_init(&hTable_JE6ljEEX, 256);
  numBytes += cDelay_init(this, &cDelay_NYWpLtsK, 0.0f);
  numBytes += cDelay_init(this, &cDelay_sqOd4bad, 0.0f);
  numBytes += hTable_init(&hTable_shzvadb8, 256);
  numBytes += cVar_init_f(&cVar_cQTVA1aS, 14.0f);
  numBytes += cBinop_init(&cBinop_WLsjmjOp, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_R99hWwBR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oElO22RT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_kvMoh0sn, 14.0f);
  numBytes += cBinop_init(&cBinop_ez6e8qXA, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FYrFpHVW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Jn2W1BIT, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_6e7Kqid1, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_Gmb8zixx, 1, -1);
  numBytes += cVar_init_f(&cVar_KljMFAge, 0.2f);
  numBytes += cSlice_init(&cSlice_GEbsPAHP, 1, -1);
  numBytes += cVar_init_f(&cVar_sC3YrW4a, 0.0f);
  numBytes += cSlice_init(&cSlice_LITVJAJR, 1, -1);
  numBytes += cVar_init_f(&cVar_sOUqmJRI, 2.0f);
  numBytes += cSlice_init(&cSlice_6P7Cv8nC, 1, -1);
  numBytes += cVar_init_f(&cVar_suoeStLM, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_JE6ljEEX);
  hTable_free(&hTable_shzvadb8);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_JE6ljEEX; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_shzvadb8; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yB7b3noo_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y0vV75QU_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jeeF4WHE_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fzBHJLrP_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VIqcbnJN_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ca5Y7bQr_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UwSJD4V6_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qeiQRl9h_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7hpMWX60_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_5CTQWfVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7TTMpLPU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_jiG3qgQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Chwb1Fyz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_LLEf967r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ptjB8aG8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_l0hf1UN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vnQ1HU3i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_9uxeh3Bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jlMb8qAG_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_jlMb8qAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_HIREvdEG, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_vKw0iWlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gQm6qfbf_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_gQm6qfbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_X1CphpCl_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_UXeJIbHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dMpIlBpM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_ke37skfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_otMWGs37_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_yVaiaPsc, m);
}

void Heavy_WSTD_FLANGR::cBinop_X1CphpCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cO1tYZqI, m);
}

void Heavy_WSTD_FLANGR::cMsg_dMpIlBpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ke37skfc_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_otMWGs37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8QGK8ZVM, m);
}

void Heavy_WSTD_FLANGR::cMsg_7jBDAiIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kxdlFxRk_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_kxdlFxRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_I93dj5sv_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_1UUKUzd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vdvzrH02_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_aimuqAmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_DCDjM6QX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XdazxHx0, m);
}

void Heavy_WSTD_FLANGR::cBinop_I93dj5sv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3RK3o5MP, m);
}

void Heavy_WSTD_FLANGR::cMsg_vdvzrH02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aimuqAmo_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_DCDjM6QX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rBlwhZ90, m);
}

void Heavy_WSTD_FLANGR::cBinop_AtDvsCic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FFeTYzZb_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_FFeTYzZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Un3m9XRC_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_drbOxXlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WgD6gPMs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_W9RoGBq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_34xWahU4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Un3m9XRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0dNzpbyF_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_0dNzpbyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U4f4EFpN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bNcfDLzF_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_bNcfDLzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H8da1BUh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_U4f4EFpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GyZm7aBk_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_GyZm7aBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uI6XzRlD_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_H8da1BUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_E8ncGFrp_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_E8ncGFrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_99tlNn30_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_uI6XzRlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_drbOxXlS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_99tlNn30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_W9RoGBq4_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_h1A0OxXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xmC0OE5M_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_xmC0OE5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tGZw00Kh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_HtYDO6Hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2XyxMHzj_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_2XyxMHzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wiFYEsl6_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_S3kUwRir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S3kUwRir, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DQeMmyz9, 0, m, &cDelay_DQeMmyz9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_S3kUwRir, 0, m, &cDelay_S3kUwRir_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ZKEHILGr, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_DQeMmyz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DQeMmyz9, m);
  cMsg_7MAv21qO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_oiIgWsGG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_HRKtwSPQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_t8so0meh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gidvZXHY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_JE6ljEEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p3yPHOmX_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_S3kUwRir, 2, m, &cDelay_S3kUwRir_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E1TFv5lz_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_gidvZXHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_JE6ljEEX, 0, m, &hTable_JE6ljEEX_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_wiFYEsl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_t8so0meh_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_7MAv21qO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_JE6ljEEX, 0, m, &hTable_JE6ljEEX_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_E1TFv5lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_S3kUwRir, 0, m, &cDelay_S3kUwRir_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_p3yPHOmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_DQeMmyz9, 2, m, &cDelay_DQeMmyz9_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_HRKtwSPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ZKEHILGr, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_9E5I6MsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cFxgzD7T_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_cFxgzD7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XLGXTDxq_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_NYWpLtsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NYWpLtsK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sqOd4bad, 0, m, &cDelay_sqOd4bad_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYWpLtsK, 0, m, &cDelay_NYWpLtsK_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CIzgmCer, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_sqOd4bad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sqOd4bad, m);
  cMsg_iTT227ON_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_txqQDi1z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Ghs0ynWW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_yW0T2NuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_16APeVXN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_shzvadb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rmDFazHD_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYWpLtsK, 2, m, &cDelay_NYWpLtsK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W8SuGKtE_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_16APeVXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_shzvadb8, 0, m, &hTable_shzvadb8_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_XLGXTDxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_yW0T2NuV_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_iTT227ON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_shzvadb8, 0, m, &hTable_shzvadb8_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_W8SuGKtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYWpLtsK, 0, m, &cDelay_NYWpLtsK_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_rmDFazHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_sqOd4bad, 2, m, &cDelay_sqOd4bad_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Ghs0ynWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CIzgmCer, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_cQTVA1aS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WLsjmjOp, HV_BINOP_MULTIPLY, 0, m, &cBinop_WLsjmjOp_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_1x0JyggD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Hxpk1G2N_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_Hxpk1G2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SEgO5Tj8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_WLsjmjOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_W4y3WoUi_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_M0mK5sDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WLsjmjOp, HV_BINOP_MULTIPLY, 1, m, &cBinop_WLsjmjOp_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_SEgO5Tj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_M0mK5sDe_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_W4y3WoUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_THSmfnXv_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_THSmfnXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fQZPdI9D_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oElO22RT, m);
}

void Heavy_WSTD_FLANGR::cBinop_fQZPdI9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_R99hWwBR, m);
}

void Heavy_WSTD_FLANGR::cVar_kvMoh0sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ez6e8qXA, HV_BINOP_MULTIPLY, 0, m, &cBinop_ez6e8qXA_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_XVdpQk8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7yp2PBrT_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_7yp2PBrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_faWXGzEn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_ez6e8qXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cjtEp345_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_FcsjitMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ez6e8qXA, HV_BINOP_MULTIPLY, 1, m, &cBinop_ez6e8qXA_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_faWXGzEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FcsjitMD_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_cjtEp345_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tKYgePlp_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_tKYgePlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5mRUxZOB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Jn2W1BIT, m);
}

void Heavy_WSTD_FLANGR::cBinop_5mRUxZOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FYrFpHVW, m);
}

void Heavy_WSTD_FLANGR::cMsg_tGZw00Kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_59wtxHrn, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_IQhDp7ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_osiEMNCf_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_gAZ0M7u4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_IQhDp7ag_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_0y897EcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4nnSiPxp_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_hBgYSLJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cGNTvwYr_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_cGNTvwYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6e7Kqid1, HV_BINOP_MULTIPLY, 1, m, &cBinop_6e7Kqid1_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_4nnSiPxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_hBgYSLJF_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_6e7Kqid1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Oqla7G3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_osiEMNCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6e7Kqid1, HV_BINOP_MULTIPLY, 0, m, &cBinop_6e7Kqid1_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_1Oqla7G3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0rE0H9rZ, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_i4Aed2hD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_mOQw3LyJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_mOQw3LyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0y897EcW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gAZ0M7u4_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_DYx93wOq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Gmb8zixx, 0, m, &cSlice_Gmb8zixx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_k1otiUwE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_Gmb8zixx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rV0k7SmX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rV0k7SmX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_KljMFAge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rV0k7SmX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_rV0k7SmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ca5Y7bQr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_k1otiUwE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GEbsPAHP, 0, m, &cSlice_GEbsPAHP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dDIQKj24_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_GEbsPAHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0GzCDYjN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0GzCDYjN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_sC3YrW4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0GzCDYjN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_0GzCDYjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VIqcbnJN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_dDIQKj24_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LITVJAJR, 0, m, &cSlice_LITVJAJR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_to3reQan_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_LITVJAJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ktmNoDsH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ktmNoDsH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_sOUqmJRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ktmNoDsH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_ktmNoDsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qeiQRl9h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_to3reQan_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6P7Cv8nC, 0, m, &cSlice_6P7Cv8nC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_6P7Cv8nC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_C1NxZpCk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_C1NxZpCk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_suoeStLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C1NxZpCk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_C1NxZpCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UwSJD4V6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_WgD6gPMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kyvd6G8O, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_34xWahU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H3sn8CpB, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_vnQ1HU3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DYx93wOq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_7TTMpLPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DYx93wOq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_Chwb1Fyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DYx93wOq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_ptjB8aG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DYx93wOq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_EkC2RMsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l0hf1UN2, 0, m, &cVar_l0hf1UN2_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Rb5ZXZnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5CTQWfVC, 0, m, &cVar_5CTQWfVC_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_1RwHBu3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LLEf967r, 0, m, &cVar_LLEf967r_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_qeiQRl9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_9uxeh3Bm_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_VIqcbnJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_i4Aed2hD_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_7hpMWX60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1x0JyggD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cQTVA1aS, 0, m, &cVar_cQTVA1aS_sendMessage);
  cMsg_XVdpQk8L_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kvMoh0sn, 0, m, &cVar_kvMoh0sn_sendMessage);
  cMsg_HtYDO6Hl_sendMessage(_c, 0, m);
  cMsg_9E5I6MsF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KljMFAge, 0, m, &cVar_KljMFAge_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sC3YrW4a, 0, m, &cVar_sC3YrW4a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sOUqmJRI, 0, m, &cVar_sOUqmJRI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_suoeStLM, 0, m, &cVar_suoeStLM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UXeJIbHS, 0, m, &cVar_UXeJIbHS_sendMessage);
  cMsg_vKw0iWlq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1UUKUzd6, 0, m, &cVar_1UUKUzd6_sendMessage);
  cMsg_7jBDAiIQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_UwSJD4V6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AtDvsCic_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_ca5Y7bQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_h1A0OxXm_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_fzBHJLrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jiG3qgQB, 0, m, &cVar_jiG3qgQB_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_jeeF4WHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_EkC2RMsU_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_Y0vV75QU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1RwHBu3l_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_yB7b3noo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Rb5ZXZnC_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_H3sn8CpB, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_HIREvdEG, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_59wtxHrn, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_oElO22RT, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_R99hWwBR, VOf(Bf3));
    __hv_rpole_f(&sRPole_yG3CRDc5, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Jn2W1BIT, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_FYrFpHVW, VOf(Bf4));
    __hv_rpole_f(&sRPole_TwIVSpr7, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_ZjUpAEcM, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_cO1tYZqI, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_8QGK8ZVM, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_yVaiaPsc, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_QI7DM5Lu, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_6wJfvaXg, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_kyvd6G8O, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_6rce78HJ, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_3RK3o5MP, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_rBlwhZ90, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_XdazxHx0, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_aiXOyJv2, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_g5ocwg1P, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_0rE0H9rZ, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_ZKEHILGr, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_CIzgmCer, VIf(Bf0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
