/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalDel1.h"
#include "HvSignalTabwrite.h"
#include "HvControlDelay.h"
#include "HvSignalLine.h"
#include "HvSignalVar.h"
#include "HvControlBinop.h"
#include "HvControlSlice.h"
#include "HvTable.h"
#include "HvSignalPhasor.h"
#include "HvControlUnop.h"
#include "HvSignalTabread.h"
#include "HvMath.h"
#include "HvSignalRPole.h"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvControlSystem.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_5CTQWfVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jiG3qgQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LLEf967r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l0hf1UN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9uxeh3Bm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jlMb8qAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vKw0iWlq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gQm6qfbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UXeJIbHS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ke37skfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X1CphpCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dMpIlBpM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_otMWGs37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7jBDAiIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kxdlFxRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1UUKUzd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aimuqAmo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I93dj5sv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vdvzrH02_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DCDjM6QX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AtDvsCic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FFeTYzZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_drbOxXlS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_W9RoGBq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Un3m9XRC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0dNzpbyF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bNcfDLzF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U4f4EFpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GyZm7aBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H8da1BUh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E8ncGFrp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uI6XzRlD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_99tlNn30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h1A0OxXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xmC0OE5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HtYDO6Hl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2XyxMHzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_S3kUwRir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DQeMmyz9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oiIgWsGG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_t8so0meh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_JE6ljEEX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gidvZXHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wiFYEsl6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7MAv21qO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E1TFv5lz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p3yPHOmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HRKtwSPQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9E5I6MsF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cFxgzD7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NYWpLtsK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sqOd4bad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_txqQDi1z_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_yW0T2NuV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_shzvadb8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_16APeVXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XLGXTDxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iTT227ON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W8SuGKtE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rmDFazHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ghs0ynWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cQTVA1aS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1x0JyggD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Hxpk1G2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WLsjmjOp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M0mK5sDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SEgO5Tj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W4y3WoUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_THSmfnXv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fQZPdI9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kvMoh0sn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XVdpQk8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7yp2PBrT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ez6e8qXA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FcsjitMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_faWXGzEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cjtEp345_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tKYgePlp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5mRUxZOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tGZw00Kh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IQhDp7ag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gAZ0M7u4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0y897EcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hBgYSLJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cGNTvwYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4nnSiPxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6e7Kqid1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_osiEMNCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1Oqla7G3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i4Aed2hD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mOQw3LyJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DYx93wOq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Gmb8zixx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KljMFAge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rV0k7SmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_k1otiUwE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_GEbsPAHP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sC3YrW4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0GzCDYjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dDIQKj24_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LITVJAJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sOUqmJRI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ktmNoDsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_to3reQan_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_6P7Cv8nC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_suoeStLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_C1NxZpCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WgD6gPMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_34xWahU4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vnQ1HU3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7TTMpLPU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Chwb1Fyz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ptjB8aG8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EkC2RMsU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rb5ZXZnC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1RwHBu3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qeiQRl9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VIqcbnJN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7hpMWX60_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UwSJD4V6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ca5Y7bQr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fzBHJLrP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jeeF4WHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Y0vV75QU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yB7b3noo_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_H3sn8CpB;
  SignalPhasor sPhasor_HIREvdEG;
  SignalLine sLine_59wtxHrn;
  SignalRPole sRPole_yG3CRDc5;
  SignalRPole sRPole_TwIVSpr7;
  SignalTabhead sTabhead_ZjUpAEcM;
  SignalTabread sTabread_QI7DM5Lu;
  SignalTabread sTabread_6wJfvaXg;
  SignalLine sLine_kyvd6G8O;
  SignalTabhead sTabhead_6rce78HJ;
  SignalTabread sTabread_aiXOyJv2;
  SignalTabread sTabread_g5ocwg1P;
  SignalLine sLine_0rE0H9rZ;
  SignalTabwrite sTabwrite_ZKEHILGr;
  SignalTabwrite sTabwrite_CIzgmCer;
  ControlVar cVar_5CTQWfVC;
  ControlVar cVar_jiG3qgQB;
  ControlVar cVar_LLEf967r;
  ControlVar cVar_l0hf1UN2;
  ControlBinop cBinop_9uxeh3Bm;
  ControlBinop cBinop_jlMb8qAG;
  ControlVar cVar_UXeJIbHS;
  ControlBinop cBinop_X1CphpCl;
  ControlBinop cBinop_otMWGs37;
  SignalVarf sVarf_yVaiaPsc;
  SignalVarf sVarf_cO1tYZqI;
  SignalVarf sVarf_8QGK8ZVM;
  ControlVar cVar_1UUKUzd6;
  ControlBinop cBinop_I93dj5sv;
  ControlBinop cBinop_DCDjM6QX;
  SignalVarf sVarf_XdazxHx0;
  SignalVarf sVarf_3RK3o5MP;
  SignalVarf sVarf_rBlwhZ90;
  ControlBinop cBinop_AtDvsCic;
  ControlBinop cBinop_FFeTYzZb;
  ControlBinop cBinop_Un3m9XRC;
  ControlBinop cBinop_0dNzpbyF;
  ControlBinop cBinop_GyZm7aBk;
  ControlBinop cBinop_E8ncGFrp;
  ControlBinop cBinop_uI6XzRlD;
  ControlBinop cBinop_99tlNn30;
  ControlBinop cBinop_h1A0OxXm;
  ControlBinop cBinop_xmC0OE5M;
  ControlDelay cDelay_S3kUwRir;
  ControlDelay cDelay_DQeMmyz9;
  ControlBinop cBinop_t8so0meh;
  HvTable hTable_JE6ljEEX;
  ControlBinop cBinop_wiFYEsl6;
  ControlDelay cDelay_NYWpLtsK;
  ControlDelay cDelay_sqOd4bad;
  ControlBinop cBinop_yW0T2NuV;
  HvTable hTable_shzvadb8;
  ControlBinop cBinop_XLGXTDxq;
  ControlVar cVar_cQTVA1aS;
  ControlBinop cBinop_WLsjmjOp;
  ControlBinop cBinop_M0mK5sDe;
  SignalVarf sVarf_R99hWwBR;
  ControlBinop cBinop_W4y3WoUi;
  ControlBinop cBinop_THSmfnXv;
  ControlBinop cBinop_fQZPdI9D;
  SignalVarf sVarf_oElO22RT;
  ControlVar cVar_kvMoh0sn;
  ControlBinop cBinop_ez6e8qXA;
  ControlBinop cBinop_FcsjitMD;
  SignalVarf sVarf_FYrFpHVW;
  ControlBinop cBinop_cjtEp345;
  ControlBinop cBinop_tKYgePlp;
  ControlBinop cBinop_5mRUxZOB;
  SignalVarf sVarf_Jn2W1BIT;
  ControlBinop cBinop_hBgYSLJF;
  ControlBinop cBinop_cGNTvwYr;
  ControlBinop cBinop_4nnSiPxp;
  ControlBinop cBinop_6e7Kqid1;
  ControlBinop cBinop_osiEMNCf;
  ControlBinop cBinop_i4Aed2hD;
  ControlBinop cBinop_mOQw3LyJ;
  ControlSlice cSlice_Gmb8zixx;
  ControlVar cVar_KljMFAge;
  ControlSlice cSlice_GEbsPAHP;
  ControlVar cVar_sC3YrW4a;
  ControlSlice cSlice_LITVJAJR;
  ControlVar cVar_sOUqmJRI;
  ControlSlice cSlice_6P7Cv8nC;
  ControlVar cVar_suoeStLM;
  ControlBinop cBinop_EkC2RMsU;
  ControlBinop cBinop_Rb5ZXZnC;
  ControlBinop cBinop_1RwHBu3l;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
